/*
 *	Copyright (C) 2007, 2008. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvippworkers.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <QVWorker>
#include <qvipp.h>
#include <QVIndexedStringList>

#ifndef QVIPPWORKERS_H
#define QVIPPWORKERS_H

#ifndef DOXYGEN_IGNORE_THIS
const QStringList getQvippWorkersNames();
QVPropertyContainer *newQvippWorker(QString type, QString name);

// CopyP3C3 Worker
template <typename TYPE> class qvippCopyP3C3Worker: public QVWorker
	{
	public:
		qvippCopyP3C3Worker(QString name);
		void iterate();
	};

// CopyC3P3 Worker
template <typename TYPE> class qvippCopyC3P3Worker: public QVWorker
	{
	public:
		qvippCopyC3P3Worker(QString name);
		void iterate();
	};
// Dilate3x3 Worker
template <typename TYPE, int C> class qvippDilate3x3Worker: public QVWorker
	{
	public:
		qvippDilate3x3Worker(QString name);
		void iterate();
	};

// Erode3x3 Worker
template <typename TYPE, int C> class qvippErode3x3Worker: public QVWorker
	{
	public:
		qvippErode3x3Worker(QString name);
		void iterate();
	};
// ComputeThreshold_Otsu Worker
template <typename TYPE, int C> class qvippComputeThreshold_OtsuWorker: public QVWorker
	{
	public:
		qvippComputeThreshold_OtsuWorker(QString name);
		void iterate();
	};

// AddRandUniform_Direct Worker
template <typename TYPE, int C> class qvippAddRandUniform_DirectWorker: public QVWorker
	{
	private:
		unsigned int seed;

	public:
		qvippAddRandUniform_DirectWorker(QString name);
		void iterate();
	};

// FilterBox Worker
template <typename TYPE, int C> class qvippFilterBoxWorker: public QVWorker
	{
	public:
		qvippFilterBoxWorker(QString name);
		void iterate();
	};

// FilterMedian Worker
template <typename TYPE, int C> class qvippFilterMedianWorker: public QVWorker
	{
	public:
		qvippFilterMedianWorker(QString name);
		void iterate();
	};

// FilterMax Worker
template <typename TYPE, int C> class qvippFilterMaxWorker: public QVWorker
	{
	public:
		qvippFilterMaxWorker(QString name);
		void iterate();
	};

// FilterMin Worker
template <typename TYPE, int C> class qvippFilterMinWorker: public QVWorker
	{
	public:
		qvippFilterMinWorker(QString name);
		void iterate();
	};

// FilterGauss Worker
template <typename TYPE, int C> class qvippFilterGaussWorker: public QVWorker
	{
	public:
		qvippFilterGaussWorker(QString name);
		void iterate();
	};

// FilterHipass Worker
template <typename TYPE, int C> class qvippFilterHipassWorker: public QVWorker
	{
	public:
		qvippFilterHipassWorker(QString name);
		void iterate();
	};

// Add Worker
template <typename TYPE, int C> class qvippAddWorker: public QVWorker
	{
	public:
		qvippAddWorker(QString name);
		void iterate();
	};

// AddC Worker
template <typename TYPE, int C> class qvippAddCWorker: public QVWorker
	{
	public:
		qvippAddCWorker(QString name);
		void iterate();
	};

// CompareC Worker
template <typename TYPE, int C> class qvippCompareCWorker: public QVWorker
	{
	public:
		qvippCompareCWorker(QString name);
		void iterate();
	};

#endif

#endif
